BoundingBox

Struct BoundingBox 

pub struct BoundingBox {
    pub min_x: f64,
    pub min_y: f64,
    pub max_x: f64,
    pub max_y: f64,
}
A 2D bounding box in any coordinate system

The bounding box is defined by its minimum and maximum coordinates. Coordinates can be in any unit (degrees, meters, etc.) depending on the CRS.

Fields

min_x: f64

Minimum X coordinate (west)

min_y: f64

Minimum Y coordinate (south)

max_x: f64

Maximum X coordinate (east)

max_y: f64

Maximum Y coordinate (north)

Implementations

Source

impl BoundingBox

pub fn new( min_x: f64, min_y: f64, max_x: f64, max_y: f64, ) -> Result<BoundingBox, OxiGdalError>

Creates a new bounding box from min/max coordinates

Arguments
  • min_x - Minimum X coordinate
  • min_y - Minimum Y coordinate
  • max_x - Maximum X coordinate
  • max_y - Maximum Y coordinate
Errors

Returns an error if min > max for either axis

pub const fn new_unchecked( min_x: f64, min_y: f64, max_x: f64, max_y: f64, ) -> BoundingBox

Creates a new bounding box without validation

Safety

This is safe but may create invalid bounding boxes where min > max. Use BoundingBox::new for validated construction.

pub fn from_wsen( west: f64, south: f64, east: f64, north: f64, ) -> Result<BoundingBox, OxiGdalError>

Creates a bounding box from (west, south, east, north) coordinates

This is a common ordering used in many geospatial APIs.

Errors

Returns an error if coordinates are invalid

pub const fn point(x: f64, y: f64) -> BoundingBox

Creates a point bounding box (zero area)

pub const fn world_wgs84() -> BoundingBox

Creates the world bounds in WGS84 coordinates

pub const fn world_web_mercator() -> BoundingBox

Creates the world bounds in Web Mercator coordinates (EPSG:3857)

pub const fn min_x(&self) -> f64

Returns the minimum X coordinate (west)

pub const fn min_y(&self) -> f64

Returns the minimum Y coordinate (south)

pub const fn max_x(&self) -> f64

Returns the maximum X coordinate (east)

pub const fn max_y(&self) -> f64

Returns the maximum Y coordinate (north)

pub fn width(&self) -> f64

Returns the width of the bounding box

pub fn height(&self) -> f64

Returns the height of the bounding box

pub fn area(&self) -> f64

Returns the area of the bounding box

pub fn center(&self) -> (f64, f64)

Returns the center point of the bounding box

pub fn contains_point(&self, x: f64, y: f64) -> bool

Returns true if this bounding box contains the given point

pub fn contains(&self, other: &BoundingBox) -> bool

Returns true if this bounding box fully contains another bounding box

pub fn is_within(&self, other: &BoundingBox) -> bool

Returns true if this bounding box is fully within another bounding box

This is the inverse of contains().

pub fn intersects(&self, other: &BoundingBox) -> bool

Returns true if this bounding box intersects with another

pub fn intersection(&self, other: &BoundingBox) -> Option<BoundingBox>

Returns the intersection of two bounding boxes, if any

pub fn union(&self, other: &BoundingBox) -> BoundingBox

Returns the union of two bounding boxes

pub fn expand(&self, amount: f64) -> BoundingBox

Expands the bounding box by the given amount in all directions

pub fn expand_to_include(&self, x: f64, y: f64) -> BoundingBox

Expands the bounding box to include the given point

pub fn is_empty(&self) -> bool

Returns true if the bounding box has zero area

pub fn is_valid(&self) -> bool

Returns true if the bounding box is valid (finite values, min <= max)

pub const fn as_array(&self) -> [f64; 4]

Returns the bounding box as an array [min_x, min_y, max_x, max_y]

pub const fn as_wsen(&self) -> (f64, f64, f64, f64)

Returns the bounding box as (west, south, east, north) tuple

pub fn from_array(arr: [f64; 4]) -> Result<BoundingBox, OxiGdalError>

Creates a bounding box from an array [min_x, min_y, max_x, max_y]

Errors

Returns an error if the array represents an invalid bounding box